@@ -73,14 +73,12 @@
  
 	for (i in 1:nbands) {
 		b <- new("GDALRasterBand", transient, i)
-		.gd_SetNoDataValue <- eval(parse(text="rgdal:::.gd_SetNoDataValue"))
-		.gd_SetNoDataValue(b, NAflag)
+		GDALcall(b, "SetNoDataValue", NAflag)
 		if (hasCT) {
-			.gd_SetRasterColorTable <- eval(parse(text="rgdal:::.gd_SetRasterColorTable"))
-			.gd_SetRasterColorTable(b, t(col2rgb(ct, TRUE)))
+			GDALcall(b, "SetRasterColorTable", t(col2rgb(ct, TRUE)))
 		}
 	}
-
+	
 	if (rotated(r)) {
 		gt <- r@rotation@geotrans
 	} else {
@@ -92,11 +90,9 @@
 		#}
 	}
 
-	.gd_SetGeoTransform <- eval(parse(text="rgdal:::.gd_SetGeoTransform"))
-	.gd_SetGeoTransform(transient, gt)
-	.gd_SetProject <- eval(parse(text="rgdal:::.gd_SetProject"))	
-	.gd_SetProject(transient, projection(r))
-		
+	GDALcall(transient, "SetGeoTransform", gt)
+	# as.character to ensure NA is character
+	GDALcall(transient, "SetProject", as.character(projection(r))) 
 	if (is.null(options)) {
 		options <- ''
 	}
