@@ -108,6 +108,8 @@ setMethod('brick', signature(x='RasterStack'),
 				b <- writeStart(b, filename=filename, ...)
 				tr <- blockSize(b)
 				pb <- pbCreate(tr$n, ...)			
+				x <- readStart(x)
+
 				for (i in 1:tr$n) {
 					vv <- getValues(x, row=tr$row[i], nrows=tr$nrows[i])
 					b <- writeValues(b, vv, tr$row[i])
@@ -115,6 +117,7 @@ setMethod('brick', signature(x='RasterStack'),
 				}
 				pbClose(pb)
 				b <- writeStop(b)
+				x <- readStop(x)
 				return(b)
 			}
 			
