@@ -4,7 +4,7 @@
 # Licence GPL v3
 
 
-.rasterFromASCIIFile <- function(filename, offset=6, ...) {
+.rasterFromASCIIFile <- function(filename, offset=6, crs=NULL, ...) {
 	
 	offset <- as.integer(offset)
 	stopifnot(offset > 2)
@@ -113,6 +113,11 @@
 	x@file@nodatavalue <- nodataval
     x@file@name <- filename
 	
+	
+	if (!is.null(crs)) {
+		projection(x) <- crs
+	}
+	
 	return(x)
 }
 
